==> endeavour_2.3.2.orig.tar.gz: endeavour-2.3.2/endeavour2/findwincb.h <==
/*
                       Endeavour Find Window Callbacks
 */

#ifndef FINDWINCB_H
#define FINDWINCB_H

#include <gtk/gtk.h>
#include "edvtypes.h"
#include "findwin.h"


extern void EDVFindWinListItemDestroyCB(gpointer data);

extern gint EDVFindWinDeleteEventCB(
        GtkWidget *widget, GdkEvent *event, gpointer data
);
extern void EDVFindWinDestroyCB(GtkObject *object, gpointer data);

extern gint EDVFindWinCrossingCB(
        GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
);
extern gint EDVFindWinButtonCB(
	GtkWidget *widget, GdkEventButton *button, gpointer data
);

extern void EDVFindWinComboActivateCB(GtkWidget *widget, gpointer data);

extern gint EDVFindWinFindProgressCB(
        const gchar *path, gfloat progress, gpointer data
);

extern void EDVFindWinFindMatchedExcerptCB(
        const gchar *path, const struct stat *lstat_buf, const gchar *excerpt,
        gpointer data
);
extern void EDVFindWinFindMatchedCB(
        const gchar *path, const struct stat *lstat_buf,
        gpointer data
);

extern void EDVFindWinClickColumnCB(
        GtkCList *clist, gint column, gpointer data
);
extern void EDVFindWinSelectRowCB(
        GtkCList *clist, gint row, gint column, GdkEvent *event,
        gpointer data
);
extern void EDVFindWinUnselectRowCB(
        GtkCList *clist, gint row, gint column, GdkEvent *event,
        gpointer data
);

extern void EDVFindWinSearchCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinStopCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinClearCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinCloseCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinOpenCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinOpenWithCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinGotoCB(GtkWidget *widget, gpointer data);

void EDVFindWinWriteProtectChangedCB(
        edv_findwin_struct *fw, gbool state
);


#endif	/* FINDWINCB_H */

==> endeavour_2.5.2.orig.tar.gz: endeavour-2.5.2/endeavour2/findwincb.h <==
/*
		       Endeavour Find Window Callbacks
 */

#ifndef FINDWINCB_H
#define FINDWINCB_H

#include <gtk/gtk.h>
#include "edvtypes.h"
#include "findwin.h"


extern void EDVFindWinListItemDestroyCB(gpointer data);

extern gint EDVFindWinDeleteEventCB(
	GtkWidget *widget, GdkEvent *event, gpointer data
);
extern void EDVFindWinDestroyCB(GtkObject *object, gpointer data);

extern gint EDVFindWinCrossingCB(
	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
);
extern gint EDVFindWinButtonCB(
	GtkWidget *widget, GdkEventButton *button, gpointer data
);

extern void EDVFindWinComboActivateCB(GtkWidget *widget, gpointer data);

extern gint EDVFindWinFindProgressCB(
	const gchar *path, gfloat progress, gpointer data
);

extern void EDVFindWinFindMatchedExcerptCB(
	const gchar *path, const struct stat *lstat_buf,
	const gchar *excerpt, gint line_index,
	gpointer data
);
extern void EDVFindWinFindMatchedCB(
	const gchar *path, const struct stat *lstat_buf,
	gpointer data
);

extern void EDVFindWinClickColumnCB(
	GtkCList *clist, gint column, gpointer data
);
extern void EDVFindWinSelectRowCB(
	GtkCList *clist, gint row, gint column, GdkEvent *event,
	gpointer data
);
extern void EDVFindWinUnselectRowCB(
	GtkCList *clist, gint row, gint column, GdkEvent *event,
	gpointer data
);

extern void EDVFindWinSearchCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinStopCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinClearCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinCloseCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinOpenCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinOpenWithCB(GtkWidget *widget, gpointer data);
extern void EDVFindWinGotoCB(GtkWidget *widget, gpointer data);

extern void EDVFindWinWriteProtectChangedCB(
	edv_findwin_struct *fw, gboolean state
);
extern void EDVFindWinReconfiguredNotifyCB(edv_findwin_struct *fw);


#endif	/* FINDWINCB_H */
